#
# spec file for package lalinspiral
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif

%define pname lalinspiral

%define shlib lib%{name}18
# NEP 29: python36-numpy and co. in TW are no more
%define skip_python36 1
# Py2 dropped by upstream
%define skip_python2 1
# octave >= 6 not supported
%bcond_with octave
Name:           %{pname}%{?psuffix}
Version:        5.0.1
Release:        2.4
Summary:        LSC Algorithm Inspiral Library
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Physics
URL:            https://wiki.ligo.org/Computing/LALSuite
Source:         https://software.igwn.org/sources/source/lalsuite/%{pname}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         https://git.ligo.org/lscsoft/lalsuite/-/commit/9dba245ab3692ecf691247a442704f13c075ed34.patch#/lalinspiral-swig-stringval-not-value.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.7}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(lal) >= 7.2.0
BuildRequires:  pkgconfig(lalburst) >= 1.6.0
BuildRequires:  pkgconfig(lalframe) >= 2.0.0
BuildRequires:  pkgconfig(lalmetaio) >= 3.0.0
BuildRequires:  pkgconfig(lalsimulation) >= 4.0.0
Requires:       python-glue
Requires:       python-lal >= 7.2.0
Requires:       python-lalburst >= 1.6.0
Requires:       python-lalframe >= 2.0.0
Requires:       python-lalmetaio >= 3.0.0
Requires:       python-lalsimulation >= 4.0.0
Requires:       python-numpy >= 1.7
ExcludeArch:    %{ix86}
%if 0%{?suse_version} < 1550
BuildRequires:  python-xml
%endif
%if %{with octave}
BuildRequires:  octave-lal >= 7.2.0
BuildRequires:  octave-lalburst >= 1.6.0
BuildRequires:  octave-lalframe >= 2.0.0
BuildRequires:  octave-lalmetaio >= 3.0.0
BuildRequires:  octave-lalsimulation >= 4.0.0
BuildRequires:  pkgconfig(octave)
%endif
# SECTION For tests (python3 only)
%if %{with test}
BuildRequires:  %{python_module glue}
BuildRequires:  %{python_module lal >= 7.2.0}
BuildRequires:  %{python_module lalburst >= 1.6.0}
BuildRequires:  %{python_module lalframe >= 2.0.0}
BuildRequires:  %{python_module lalinspiral >= 3.0.0}
BuildRequires:  %{python_module lalmetaio >= 3.0.0}
BuildRequires:  %{python_module lalsimulation >= 4.0.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module py}
BuildRequires:  pkgconfig(lalinspiral) = %{version}
%endif
# /SECTION
%python_subpackages

%description
The LSC Algorithm Inspiral Library for gravitational wave data analysis.

%package -n %{shlib}
Summary:        Shared library for LAL Inspiral
Group:          Productivity/Scientific/Physics

%description -n %{shlib}
This package contains the shared-object libraries needed to run applications
that use the LAL Inspiral library.

%package -n %{name}-devel
Summary:        Development files for LAL Inspiral
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       pkgconfig(gsl)
Requires:       pkgconfig(lal) >= 7.2.0
Requires:       pkgconfig(lalframe) >= 2.0.0
Requires:       pkgconfig(lalmetaio) >= 3.0.0
Requires:       pkgconfig(lalsimulation) >= 4.0.0
%if %{with octave}
Requires:       pkgconfig(octave)
%endif

%description -n %{name}-devel
This package contains sources and header files needed to build applications
that use the LAL Inspiral library.

%if %{with octave}
%package -n octave-lalinspiral
Summary:        Octave bindings for LAL Inspiral
Group:          Productivity/Scientific/Physics
Requires:       octave-lal >= 7.2.0
Requires:       octave-lalframe >= 2.0.0
Requires:       octave-lalmetaio >= 3.0.0
Requires:       octave-lalsimulation >= 4.0.0
%requires_eq    octave-cli

%description -n octave-lalinspiral
This package provides the necessary files for using LAL Inspiral with octave.
%endif

%prep
# Upstream commits are -p1 against the full lalsuite, but -p2 against individual lal* pkgs
%autosetup -p2 -n %{pname}-%{version}

%build
%{python_expand # Necessary to run configure with multiple py3 flavors
export PYTHON=%{_bindir}/$python
builddir=../`basename ${PYTHON}`_build
mkdir ${builddir}
cp -pr ./ ${builddir}
pushd ${builddir}
export CFLAGS="%{optflags} -Wno-error=address"
export CXXFLAGS=${CFLAGS}
%configure \
  %{?with_octave:--enable-swig-octave} \
  %{!?with_octave:--disable-swig-octave}
%make_build %{?with_test:test}
popd
}

%install
%if %{without test}
%{python_expand # py2 and py3 make_install
export PYTHON=%{_bindir}/$python
builddir=../`basename ${PYTHON}`_build
pushd ${builddir}
%make_install
popd
}

# SECTION EXPORT LAL SPECIFIC ENV VARIABLES
# We do not use upstream's env files because they also set more generic
# variables (e.g. PATH) which may ruin setups

# NUKE UPSTREAM ENV SCRIPTS
rm %{buildroot}%{_sysconfdir}/%{name}-user-env.*

cat << EOF >> %{name}.sh
export LALINSPIRAL_PREFIX=%{_prefix}
export LALINSPIRAL_DATADIR=%{_datadir}/%{name}
EOF

cat << EOF >> %{name}.csh
setenv LALINSPIRAL_PREFIX "%{_prefix}"
setenv LALINSPIRAL_DATADIR "%{_datadir}/%{name}"
EOF

cat << EOF >> %{name}.fish
set LALINSPIRAL_PREFIX (echo "%{_prefix}" | %{_bindir}/sed -e 's| |:|g;')
set LALINSPIRAL_DATADIR (echo "%{_datadir}/%{name}" | %{_bindir}/sed -e 's| |:|g;')
EOF

install -D -m0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -D -m0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh
install -D -m0644 %{name}.fish %{buildroot}%{_sysconfdir}/profile.d/%{name}.fish

# /SECTION

# SECTION REMOVE STATIC LIB AND LIBTOOL ARCHIVE
find %{buildroot}%{_libdir}/ -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print
# /SECTION

%python_expand %fdupes %{buildroot}%{$python_sitearch}/%{name}/

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.*

%files -n %{name}-devel
%doc AUTHORS README.md
%license COPYING
%{_bindir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%config %{_sysconfdir}/profile.d/%{name}.*

%if %{with octave}
%files -n octave-%{name}
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%endif

%files %{python_files}
%{python_sitearch}/lalinspiral/

%else

%check
%{python_expand export PYTHON=%{_bindir}/$python
%make_build -C ../`basename ${PYTHON}`_build check
}

%endif

%changelog
* Sun Dec  1 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add lalinspiral-swig-stringval-not-value.patch: For
  compatibility with swig 4.3.0, prefer 'stringval' before 'value'
  attribute (upstream commit 9dba245a).
* Mon Nov 18 2024 Atri Bhattacharya <badshah400@gmail.com>
- Fix use of %%requires_eq with respect to octave.
* Wed Sep 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.1 (no release notes).
* Sat Jul 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.0:
  * No release notes.
* Mon Jan 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.4:
  * No release notes.
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.2:
  * No release notes.
- Update shlib package name in keeping with upstream so version.
* Sun Feb 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add python-py BuildRequires to fix tests that fail due to "No
  module named 'py._path'" errors.
* Tue Aug 23 2022 Atri Bhattacharya <badshah400@gmail.com>
- Fix multibuild package names.
* Fri Aug 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.0:
  * No release notes.
- Update so version to match with upstream.
- Change how build dirs are set up for multiple py flavours: the
  env variable PYTHON is used as the hashbang binary and must be
  set to the full python executable.
- Pass "-Wno-error=address" to CFLAGS to avoid errors on a minor
  warning.
- Update source URL.
- Split out testing as part of %%check section to a multibuild
  flavour; testing can take a long time slowing down builds for
  dependent packages unnecessarily.
* Sun Jan  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.4:
  * No release notes.
- Drop support for python2 in keeping with upstream.
* Fri Feb 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.2 (no release notes).
- Don't require octave-devel for devel pkg when not building with
  octave support.
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * no release notes
- Skip python36 build. Due to NEP 29, python36-numpy and co. in TW
  are no more
* Fri Jan 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix testing for multi-versioned python.
* Mon Jan 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings, since octave >= 6 isn't supported.
* Sun Oct 25 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update URL.
- Specfile cleanups using spec-cleaner,
* Sat Aug 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Implement tests as part of %%check; introduces BuildRequires:
  python3-pytest (we limit testing python modules to python3
  only).
- ExcludeArch 32-bit, as tests fail and upstream confirms that it
  is not supported
  (https://git.ligo.org/lscsoft/lalsuite/-/issues/371).
* Tue Jul  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.10.1:
  * No release notes.
- Drop lalinspiral-build-octave44-with-swig3.patch: fixed
  upstream; also drop autoreconf command before configure and
  BuildRequires: libtool, all required for this patch.
- Re-enable octave bindings: fixed upstream.
* Tue Jun 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave support as compilation error with current swig.
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- BuildRequires: python-xml only for openSUSE <= 15.2 since
  python2 is disabled for newer openSUSE.
* Mon Feb  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.10.0:
  * O3b release
- Rebase lalinspiral-build-octave44-with-swig3.patch for updated
  version.
- Drop lalinspiral-include-stdio.patch: No longer needed.
- New BuildRequires: pkgconfig(lalburst), python-lalburst,
  octave-lalburst and new Requires: python-lalburst.
* Tue Oct  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- Build packages for both python2 and python3.
* Mon Jul 22 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.9.0:
  * O3 release
- Add lalinspiral-include-stdio.patch to include a missing header
  causing build failures.
- Update shared lib package names in keeping with upstream so
  versioning.
- Rebase lalinspiral-build-octave44-with-swig3.patch to conform to
  upstream's reworking for swig and octave version tests.
* Fri Feb  8 2019 badshah400@gmail.com
- Switch builds to python2; add python-xml to BuildRequires.
* Thu Feb  7 2019 badshah400@gmail.com
- Update Requires for %%{name}-devel, octave-%%{name}, and
  python-%%{name}.
* Sun Jan 27 2019 badshah400@gmail.com
- Add lalburst-build-octave44-with-swig3.patch: allow building
  octave bindings with swig 3.0.x rather than requiring swig 4.x.
* Sun Jan 27 2019 badshah400@gmail.com
- Initial package
